function [b,a,Uba] = ReadFromFile(filename,Nb)
% read filter coefficients and associated uncertainty matrix from file
% Note that a_0 = 1 always by definition
% Assume that file contains a matrix structured as:
%
% |  b_0   u^2(b_0)   u(b_0,b_1) ... ... u(b_0,a_Na) |
% |  ...   u(b_1,b_0) u^2(b_1)   ... ...             |
% |  b_Nb                  ....  ...                 |
% |  a_1                                             |
% |  ...                                             |
% |  a_Na                                 u^2(a_Na)  |         


   file = importdata(filename);
  
   if isstruct(file)   % with header information
       b  = file.data(1:Nb,1);
       a  = [1;file.data(Nb+1:end,1)];
       Uba= file.data(1:end,2:end);
   else   % without header information
       b = file(1:Nb,1);
       a = [1;file(Nb+1:end,1)];
       Uba = file(1:end,2:end);        
   end

end